10 return ((scheme_name_len == (
int) strlen(name)) &&
11 (strncmp(scheme_name, name, scheme_name_len) == 0));
15static void initial(
const char *scheme_name,
int scheme_name_len) {
31 for (
int i = 0;
i < n;
i++) {
57 for (
int i = 0;
i < msk_size;
i++) {
66int main(
int argc,
char **argv) {
73 json_error_t json_error;
74 const char *case_json = json_dumps(json_load_file(
"cylinder.case", 0,
75 &json_error), JSON_COMPACT);
76 int *neko_case = NULL;
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ w
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ u
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ v
static void initial(const char *scheme_name, int scheme_name_len)
int main(int argc, char **argv)
static int scheme_name_is(const char *scheme_name, int scheme_name_len, const char *name)
Defines inflow dirichlet conditions.
void neko_step(int **case_iptr)
void neko_case_init(const char **case_json, int case_len, int **case_iptr)
void neko_case_allocate(int **case_iptr)
int neko_field_size(char *field_name)
void neko_case_free(int **case_iptr)
neko_real * neko_field(char *field_name)
double neko_case_end_time(int **case_iptr)
double neko_case_time(int **case_iptr)
neko_real * neko_cb_field_by_name(char *field_name)
int neko_cb_field_name_at_index(int *field_idx, char *field_name)
void neko_user_setup(int **case_iptr, neko_initial_condition_cb initial_cb, neko_preprocess_cb preprocess_cb, neko_compute_cb compute_cb, neko_dirichlet_condition_cb dirichlet_cb, neko_material_properties_cb material_cb, neko_source_term_cb source_cb)